" Vim syntax file
" Language   : C-shell (sml)
" Maintainer : Charles E. Campbell, Jr.
" Last change: December 23, 1997

" Remove any old syntax stuff hanging around
syn clear
syn case ignore

" Variables which affect the sml itself

syn keyword smlTodo	contained TODO XXX

" Variable Name Expansion Modifiers

" Catch errors caused by wrong parenthesis
"syn region smlParen	transparent start='(' end=')' contains=ALLBUT,smlParenError
"syn match smlParenError	")"
"syn match smlInParen contained	"[{}]"

syn region smlBraces	transparent start='{' end='}' contains=ALLBUT,smlBraceError
syn match smlBraceError	"}"

" Strings and Comments
syn match   smlNoEndlineDQ	contained "[^\"]\(\\\\\)*$"

syn region  smlDblQuote	start=+[^\\]"+lc=1 skip=+\\\\\|\\"+ end=+"+   contains=smlSpecial,smlNoEndlineDQ
syn region  smlSnglQuote	start=+[^\\]'+lc=1 skip=+\\\\\|\\'+ end=+'+	
syn region  smlDblQuote	start=+^"+ skip=+\\\\\|\\"+ end=+"+	          contains=smlSpecial,smlNoEndlineDQ
syn region  smlSnglQuote	start=+^'+ skip=+\\\\\|\\'+ end=+'+		
syn match   smlComment	"#.*$" contains=smlTodo

" A bunch of useful sml keywords
syn keyword smlStatement var	const	proc
syn keyword smlStatement array	raster	vector
syn keyword smlStatement cad	region	strint
syn keyword smlStatement numeric	func	return
syn keyword smlStatement if	then	else
syn keyword smlStatement while	for	each
syn keyword smlStatement foreach	step	
syn keyword smlStatement 	to	in
syn keyword smlStatement begin	end	local
syn keyword smlStatement break	go	goto
syn keyword smlStatement class	

syn keyword smlOperator and or
" Special environment variables
syn keyword smlShellVariables	HOME	LOGNAME	PATH	TERM	USER


" Highlight special characters (those which have a backslash) differently
syn match smlSpecial	contained "\\[0-9][0-9][0-9]\|\\[abcfnrtv\\]"
syn match smlNumber	"-\=\<[0-9]\+\>"
syn match smlNumber	"\<[0-9]\+\>"
syn match smlNumber	"\<[0-9]\+e[-+]\=[0-9]\+\>"
syn match smlNumber                "\<[0-9]\+\.[0-9]*\(e[-+]\=[0-9]\+\)\=[fl]\=\>"
"floating point number, starting with a dot, optional exponent
syn match smlNumber                "\.[0-9]\+\(e[-+]\=[0-9]\+\)\=[fl]\=\>"
"floating point number, without dot, with exponent
syn match smlNumber                "\<[0-9]\+e[-+]\=[0-9]\+[fl]\=\>"

" All other identifiers
syn match smlIdentifier	"\<[a-zA-Z_][a-zA-Z0-9_\$]*"

" Operators and Expression-Using constructs
syn match   smlOperator	 "\(&&\|!=\|=\|<>\|<=\|==\|>=\|\*\|\^\|\~\|||\|!\|%\|&\|+\|-\|/\|<\|>\||\)"
syn match   smlOperator	"[();]"
syn match   smlBraces	"[{}]"


if !exists("did_sml_syntax_inits_")
  let did_sml_syntax_inits = 1
  " The default methods for highlighting.  Can be overridden later
  hi link smlDblQuote	smlString
  hi link smlNoEndlineDQ	smlNoEndline
  hi link smlSnglQuote	smlString

  hi link smlCommand	Statement
  hi link smlComment	Comment
  hi link smlConditional	Conditional
  hi link smlIdentifier	Identifier
  hi link smlNoEndline	Error
  "hi link smlParenError	Error
  hi link smlBraceError	Error
  hi link smlNumber	Number
  hi link smlRepeat	Repeat
  hi link smlShellVariables	Special
  hi link smlSpecial	Special
  hi link smlStatement	Statement
  hi link smlString	String
  hi link smlTodo		Todo
  hi link smlVariables	Type

  hi smlOperator	term=bold cterm=NONE gui=NONE guifg=purple ctermfg=5
  hi smlBraces	term=bold cterm=NONE gui=NONE gui=bold guifg=purple cterm=bold ctermfg=5
endif

let b:current_syntax = "sml"

" vim: ts=18
